@@ -108,8 +108,10 @@ KIO::TransferJob *APIMetaWeblog::createUploadJob( const KURL &url, KBlog::BlogPo
     map["categories"]=list;
     map["description"]=posting->content();
     map["title"]=posting->title();
-    QDateTime date;
-    map["dateCreated"]=date.currentDateTime();
+    if (posting->creationDateTime().isValid())
+      map["dateCreated"]=posting->creationDateTime();
+    else
+      map["dateCreated"]=QDateTime::currentDateTime();
     args << map;
     args << QVariant( posting->publish(), 0 );
     return KIO::xmlrpcCall( mServerURL, getFunctionName( bloggerEditPost ), args, false );
@@ -135,8 +137,10 @@ KIO::TransferJob *APIMetaWeblog::createUploadNewJob( KBlog::BlogPosting *posting
     map["categories"]=list;
     map["description"]=posting->content();
     map["title"]=posting->title();
-    QDateTime date;
-    map["dateCreated"]=date.currentDateTime(); // TODO use original date of message?
+    if (posting->creationDateTime().isValid())
+      map["dateCreated"]=posting->creationDateTime();
+    else
+      map["dateCreated"]=QDateTime::currentDateTime();
     args << map;
     args << QVariant( posting->publish(), 0 );
     return KIO::xmlrpcCall( mServerURL, getFunctionName( bloggerNewPost ), args, false );
@@ -189,31 +193,71 @@ kdDebug() << "APIMetaWeblog::interpretCategoriesJob" << endl;
     emit error( job->errorString() );
   } else {
 kdDebug() << "APIMetaWeblog::interpretCategoriesJob, no error!" << endl;
-    QValueList<QVariant> message( trfjob->response() );
-    kdDebug () << "TOP: " << message[0].typeName() << endl;
-
-    const QMap<QString, QVariant> categories = message[0].toMap();
-    const QValueList<QString> categoryNames = categories.keys();
+    QValueList<QVariant> result( trfjob->response() );
+//     kdDebug () << "TOP: " << message[0].typeName() << endl;
+// 
+//     const QMap<QString, QVariant> categories = message[0].toMap();
+//     const QValueList<QString> categoryNames = categories.keys();
+// 
+//     QValueList<QString>::ConstIterator it = categoryNames.begin();
+//     QValueList<QString>::ConstIterator end = categoryNames.end();
+//     for ( ; it != end; ++it ) {
+//       kdDebug () << "MIDDLE: " << ( *it ) << endl;
+// 
+//       const QString name( *it );
+// 
+//       const QMap<QString, QVariant> category = categories[ *it ].toMap();
+//       const QString description( category["description"].toString() );
+// 
+//       if (  !name.isEmpty() ) {
+//         emit categoryInfoRetrieved( name, description );
+//          kdDebug()<< "Emitting categorieInfoRetrieved( name=" << name << " description=" << description << " ); " << endl;
+//       }
+//     }
+//     kdDebug() << "Emitting fetchingCategoriesFinished()" << endl;
+//     emit fetchingCategoriesFinished();
+  if( result[ 0 ].type()!=QVariant::Map && result[ 0 ].type()!=QVariant::List ){ // include fix for not metaweblog standard compatible apis with array of structs instead of struct of structs, e.g. wordpress
+    kdDebug () << "Could not list categories out of the result from the server." << endl;
+  }
+  else {
+    if( result[ 0 ].type()==QVariant::Map ){
+      const QMap<QString, QVariant> categories = result[0].toMap();
+      const QValueList<QString> categoryNames = categories.keys();
 
     QValueList<QString>::ConstIterator it = categoryNames.begin();
     QValueList<QString>::ConstIterator end = categoryNames.end();
     for ( ; it != end; ++it ) {
       kdDebug () << "MIDDLE: " << ( *it ) << endl;
-
       const QString name( *it );
-
       const QMap<QString, QVariant> category = categories[ *it ].toMap();
       const QString description( category["description"].toString() );
-
       if (  !name.isEmpty() ) {
         emit categoryInfoRetrieved( name, description );
-         kdDebug()<< "Emitting categorieInfoRetrieved( name=" << name << " description=" << description << " ); " << endl;
+        kdDebug()<< "Emitting categorieInfoRetrieved( name=" << name << " description=" << description << " ); " << endl;
       }
+     }
     }
-    kdDebug() << "Emitting fetchingCategoriesFinished()" << endl;
-    emit fetchingCategoriesFinished();
+    if( result[ 0 ].type()==QVariant::List ){// include fix for not metaweblog standard compatible apis with array of structs instead of struct of structs, e.g. wordpress
+      const QValueList<QVariant> categories = result[ 0 ].toList();
+      QValueList<QVariant>::ConstIterator it = categories.begin();
+      QValueList<QVariant>::ConstIterator end = categories.end();
+      for ( ; it != end; ++it ) {
+        kdDebug () << "MIDDLE: " << ( *it ).typeName() << endl;
+        const QMap<QString, QVariant> category = ( *it ).toMap();
+        const QString description( category["description"].toString() );
+        const QString name( category["categoryName"].toString() );
+        if (  !name.isEmpty() ) {
+          emit categoryInfoRetrieved( name, description );
+          kdDebug()<< "Emitting categorieInfoRetrieved( name=" << name << " description=" << description << " ); " << endl;
+        }
+      }
+  kdDebug() << "Emitting fetchingCategoriesFinished()" << endl;
+  emit fetchingCategoriesFinished();
+  }
   }
 }
+}
+
 
 bool APIMetaWeblog::interpretListItemsJob( KIO::Job *job )
 {
@@ -370,8 +414,8 @@ bool APIMetaWeblog::readPostingFromMap( BlogPosting *post, const QMap<QString, Q
   post->setUserID( postInfo[ "userid" ].toString() );
   post->setPostID( postInfo[ "postid" ].toString() );
 
-  QString title( postInfo[ "title" ].toString() );
-  QString description( postInfo[ "description" ].toString() );
+  QString title( postInfo[ "title" ].toString().utf8() );
+  QString description( postInfo[ "description" ].toString().utf8() );
 //   QString contents( postInfo[ "content" ].toString() ); // FIXME delete if not necessary
   QValueList<QVariant> categories( postInfo[ "categories" ].toList() );
 
