@@ -40,13 +40,13 @@
 #include <kurl.h>
 #include <kio/job.h>
 #include <kstartupinfo.h>
-#include <kiconloader.h>
+// #include <kiconloader.h>
 
 #include "kblogger.h"
 
-#if KDE_IS_VERSION(3,5,0)
-#include "kbloggerbutton.h"
-#endif
+// #if KDE_IS_VERSION(3,5,0)
+// #include "kbloggerbutton.h"
+// #endif
 
 #include "kbloggermenu.h"
 #include "kbloggerconfigdialog.h"
@@ -73,17 +73,18 @@ KBlogger::KBlogger(const QString& configFile, Type type, int actions, QWidget *p
 
 	// create the applet-widget
 	kdDebug() << "Creating Applet-widget";
-#if KDE_IS_VERSION(3,5,0)
-	kdDebug() << " for >3.5.0" << endl;
-	m_button =  new KBloggerButton(this);
-	m_button->setPanelPosition( position() );
-#else
-// Old code, maybe check for kde 3.5
-	kdDebug() << " for <3.5.0" << endl;
+// #if KDE_IS_VERSION(3,5,0)
+// 	kdDebug() << " for >3.5.0" << endl;
+// 	m_button =  new KBloggerButton(this);
+// 	m_button->setPanelPosition( position() );
+// #else
+// // Old code, maybe check for kde 3.5
+// 	kdDebug() << " for <3.5.0" << endl;
  	QVBoxLayout *appletlay = new QVBoxLayout(this);
  	m_button = new QPushButton( i18n("blog"),this );
  	appletlay->addWidget(m_button);
-#endif
+	connect(m_button, SIGNAL(clicked()), this, SLOT(slotClicked()));
+// #endif
 
 
 	if (!parent)
@@ -93,10 +94,11 @@ KBlogger::KBlogger(const QString& configFile, Type type, int actions, QWidget *p
 
 	// initialize about data
 	m_aboutData = new KAboutData("kblogger", I18N_NOOP("KBlogger"), 
-				"0.6.2", I18N_NOOP("A kicker applet for blogging."), KAboutData::License_BSD, 
+				"0.6.5", I18N_NOOP("A kicker applet for blogging."), KAboutData::License_GPL, 
 				0, 0, "http://kblogger.pwsp.net", "christian_weilbach@web.de");
 	m_aboutData->addAuthor ( "Christian Weilbach", I18N_NOOP("Main developer"), 
 				I18N_NOOP("christian_weilbach@web.de"), I18N_NOOP("whiletaker.homeip.net"));
+	m_aboutData->addAuthor ( "Antonio Aloisio", I18N_NOOP("Developer") );
 	m_aboutData->addAuthor ( "Harald Sitter", I18N_NOOP("Documentation and Support") );
 	m_aboutData->addAuthor ( "Kenneth Wimer", I18N_NOOP("Icon designer") );
 
@@ -109,16 +111,19 @@ KBlogger::KBlogger(const QString& configFile, Type type, int actions, QWidget *p
 
 	connect(m_backend, SIGNAL( error( const QString& ) ),
 			this, SLOT( handleBackendError( const QString& ) ) );
-	connect(m_backend, SIGNAL( uploadPostId( const int ) ),
-			this, SLOT( handleSuccess( const int ) ) );
-	connect(m_backend, SIGNAL( mediaInfoRetrieved( const QString& ) ),
-			this, SLOT( handleSuccess( const QString& ) ) );
 	connect(m_configDialog, SIGNAL( settingsChanged() ), 
 			this, SLOT( updateBackend() ) );
+	connect(m_backend, SIGNAL( mediaInfoRetrieved( const QString& ) ),
+			this, SLOT( handleSuccess( const QString& ) ) );
 
 	KStartupInfo::appStarted();
 }
 
+void KBlogger::slotClicked()
+{
+// 	mFileItem.run();
+	editorSlot();
+}
 
 KBlogger::~KBlogger()
 {
@@ -130,6 +135,10 @@ KBlogger::~KBlogger()
 	delete m_editor;
 }
 
+void KBlogger::handleSuccess( const QString& string ){
+	KMessageBox::information( 0, i18n( "Element %1 posted." ).arg( string )  );
+}
+
 void KBlogger::menuSlot() {
 	kdDebug() << "KBlogger::menuSlot()" << endl;
 	if( KBloggerConfig::type() != BLOGGER_API ) m_menu->setFullMenu( true );
@@ -199,15 +208,6 @@ void KBlogger::handleBackendError( const QString& error ){
 	KMessageBox::error( 0, i18n( error )  );
 }
 
-void KBlogger::handleSuccess( const int id ){
-	KMessageBox::information( 0, i18n( "Element %1 posted." ).arg( id )  );
-}
-
-void KBlogger::handleSuccess( const QString& string ){
-	KMessageBox::information( 0, i18n( "Element %1 posted." ).arg( string )  );
-}
-
-
 void KBlogger::about()
 {
 	kdDebug() << "KBlogger::about()" << endl;
@@ -235,53 +235,39 @@ void KBlogger::preferences()
 
 int KBlogger::widthForHeight( int height ) const
 {
-#if KDE_IS_VERSION(3,5,0)
-	if ( !m_button )
-	{
-		return height;
-	}
-
-	return m_button->widthForHeight( height );
-#endif
+	return 60;
 }
 
 int KBlogger::heightForWidth( int width ) const
 {
-#if KDE_IS_VERSION(3,5,0)
-	if ( !m_button )
-	{
-		return width;
-	}
-
-	return m_button->heightForWidth( width );
-#endif
+	return 60;
 }
 
 void KBlogger::resizeEvent( QResizeEvent * )
 {
-#if KDE_IS_VERSION(3,5,0)
-	if (!m_button)
-	{
-		return;
-	}
-
-	int size = 1;
-
-	size = std::max( size, 
-			 orientation() == Qt::Vertical ?
-			 	m_button->heightForWidth( width() ) :
-				m_button->widthForHeight( height() ) );
-
-	
-	if(orientation() == Vertical)
-	{
-		m_button->resize( width(), size );
-	}
-	else
-	{
-		m_button->resize( size, height() );
-	}
-#endif
+// #if KDE_IS_VERSION(3,5,0)
+// 	if (!m_button)
+// 	{
+// 		return;
+// 	}
+// 
+// 	int size = 1;
+// 
+// 	size = std::max( size, 
+// 			 orientation() == Qt::Vertical ?
+// 			 	m_button->heightForWidth( width() ) :
+// 				m_button->widthForHeight( height() ) );
+// 
+// 	
+// 	if(orientation() == Vertical)
+// 	{
+// 		m_button->resize( width(), size );
+// 	}
+// 	else
+// 	{
+// 		m_button->resize( size, height() );
+// 	}
+// #endif
 }
 
 void KBlogger::mousePressEvent(QMouseEvent *e)
