@@ -39,12 +39,12 @@
 #include "kbloggerupload.h"
 #include "kbloggermenu.h"
 
-#if KDE_IS_VERSION(3,5,0) 
-#include "kbloggerbutton.h"
-#endif
+// #if KDE_IS_VERSION(3,5,0) 
+// #include "kbloggerbutton.h"
+// #endif
 
 class KBloggerMenu;
-class KBloggerButton;
+// class KBloggerButton;
 
 class KBlogger : public KPanelApplet
 {
@@ -64,6 +64,7 @@ public:
 	virtual void preferences();
 
 public slots:
+	void slotClicked();
 	void menuSlot();
 	void editorSlot();
 	void editorSlot(int);
@@ -82,18 +83,16 @@ private:
 	KBloggerMenu* m_menu;
 	KBloggerEditor* m_editor;
 	KBloggerUpload* m_upload;
-#if KDE_IS_VERSION(3,5,0) 
-	KBloggerButton* m_button;
-#else
+// #if KDE_IS_VERSION(3,5,0) 
+// 	KBloggerButton* m_button;
+// #else
 	QPushButton* m_button;
-#endif
+// #endif
 
 private slots:
 	void updateBackend();
-
-	void handleBackendError( const QString& );
-	void handleSuccess( const int );
 	void handleSuccess( const QString& );
+	void handleBackendError( const QString& );
 };
 
 #endif
