@@ -28,6 +28,7 @@
 #include <kcombobox.h>
 #include <kpushbutton.h>
 #include <kiconloader.h>
+#include <kdatetimewidget.h>
 #include <qpixmap.h>
 #include <qstylesheet.h>
 #include <kdebug.h>
@@ -36,18 +37,20 @@
 #include "kbloggerconfigdialog.h"
 #include "kbloggerconfig.h"
 #include "kbloggerlinkdialog.h"
+#include "kbloggerhtmldialog.h"
 
 #include "kbloggereditor.h"
 #include "API_Blog.h"
 
 
 KBloggerEditor::KBloggerEditor( KBlog::APIBlog* backend, int postid, QWidget* parent, const char* name, WFlags fl)
-        : KBloggerEditorBlank(parent,name,fl), m_postid( postid ), m_linkDialog()
+        : KBloggerEditorBlank(parent,name,fl), m_postid( postid ), m_linkDialog(), m_htmlDialog()
 {
 	kdDebug() << "KBloggerEditor::KBloggerEditor()" << endl;
 	if(!m_backend) this->close();
 	m_backend=backend;
-	m_linkDialog=new KBloggerLinkDialog();
+	m_linkDialog=new KBloggerLinkDialog(this);
+	m_htmlDialog=new KBloggerHtmlDialog(this);
 
 	kdDebug() << "initialize Buttons" << endl;
 	BoldButton->setPixmap( BarIcon( QString::fromLatin1("text_bold") ) );
@@ -58,6 +61,8 @@ KBloggerEditor::KBloggerEditor( KBlog::APIBlog* backend, int postid, QWidget* pa
 			this, SLOT( toggleBold() ) );
 	connect( LinkButton, SIGNAL( clicked() ),
 			this, SLOT( linkDialogSlot() ) );
+	connect( HtmlButton, SIGNAL( clicked() ),
+			this, SLOT( htmlDialogSlot() ) );
 
 	kdDebug() << "interfaceName() " << backend->interfaceName() << endl;
 
@@ -66,6 +71,7 @@ KBloggerEditor::KBloggerEditor( KBlog::APIBlog* backend, int postid, QWidget* pa
 	if( m_backend->interfaceName()!= "Blogger API 1.0") { // Only Blogger API doesn't support a title and categories
 		TitleLineEdit->setReadOnly( false ); 
 		CategoryComboBox->setEditable( true );
+		TimeStampCheckBox->setEnabled(true);
 		KIO::TransferJob *catjob = m_backend->createListCategoriesJob( KURL::KURL( KBloggerConfig::blogId() ) );
 		connect(catjob, SIGNAL( result( KIO::Job* ) ),
 				m_backend, SLOT( interpretListCategoriesJob( KIO::Job* ) ) );
@@ -87,14 +93,30 @@ KBloggerEditor::KBloggerEditor( KBlog::APIBlog* backend, int postid, QWidget* pa
 
 	connect (m_linkDialog, SIGNAL( addLink( QString, QString ) ),
 			this, SLOT( addHtmlLink( QString, QString ) ) );
+	connect (m_htmlDialog, SIGNAL( addHtmlCode( QString ) ),
+			this, SLOT( addHtmlCode( QString ) ) );
 
-	this->show();	
+	connect(m_backend, SIGNAL( error( const QString& ) ), 
+			this, SLOT( handleBackendError( const QString& ) ) );// actually this can be called from elsewhere, too, but this shouldn't be a problem since we only want to release the send button
+
+	//Update KTimeStamp Widget
+	TimeStampKDateTime->setDateTime(QDateTime::currentDateTime());
+	show();	
+}
+
+void KBloggerEditor::handleSuccess( const int id ){
+	KMessageBox::information( 0, i18n( "Element %1 posted." ).arg( id )  );
+	close();
+}
+
+void KBloggerEditor::handleBackendError( const QString& error ){
+	SendButton->setEnabled(true);
 }
 
 KBloggerEditor::~KBloggerEditor()
 {
 	kdDebug() << "KBloggerEditor::~KBloggerEditor()" << endl;
-	delete m_linkDialog;
+	//delete m_linkDialog; // it's a child of this class then will be auto deleted!
 }
 
 void KBloggerEditor::toggleItalic(){
@@ -110,13 +132,22 @@ void KBloggerEditor::disconnectCategoriesSlot() {
 }
 
 void KBloggerEditor::linkDialogSlot(){
+	m_linkDialog->setName( ContentTextEditor->selectedText());
 	m_linkDialog->show();
 }
 
+void KBloggerEditor::htmlDialogSlot(){
+	m_htmlDialog->show();
+}
+
 void KBloggerEditor::addHtmlLink( QString target, QString name ){
 	ContentTextEditor->append( "<a href=\"" + target + "\">" + name + "</a>" );
 }
 
+void KBloggerEditor::addHtmlCode( QString code ){
+	ContentTextEditor->append( code );
+}
+
 void KBloggerEditor::loadPostSlot( KBlog::BlogPosting& posting ){
 	kdDebug() << "KBloggerEditor::loadPostSlot()" << endl;
 	TitleLineEdit->setText( posting.title() );
@@ -141,6 +172,9 @@ void KBloggerEditor::sendSlot()
 	return;
 
 	kdDebug() << "KBlog::BlogPosting()" << endl;
+	SendButton->setEnabled(false);
+	connect(m_backend, SIGNAL( uploadPostId( const int ) ),
+			this, SLOT( handleSuccess( const int ) ) );
 	KBlog::BlogPosting *posting = new KBlog::BlogPosting();
 	posting->setBlogID( KBloggerConfig::blogId() );
 	posting->setTitle( TitleLineEdit->text() );
@@ -156,7 +190,8 @@ void KBloggerEditor::sendSlot()
 	posting->setContent( richText );
 	posting->setPublish( PublishCheckbox->isChecked() );
 	posting->setCategory( CategoryComboBox->currentText() );
-
+        if ( TimeStampKDateTime->isEnabled() )
+	  posting->setCreationDateTime( TimeStampKDateTime->dateTime() );
 	KIO::TransferJob* uploadjob;
 	if( m_postid!=-1 ){
 		kdDebug() << "Creating m_backend->createUploadJob()" << endl;
