@@ -23,6 +23,7 @@
 
 #include "kbloggereditorblank.h"
 #include "kbloggerlinkdialog.h"
+#include "kbloggerhtmldialog.h"
 #include "API_Blog.h"
 
 class KBloggerEditor : public KBloggerEditorBlank
@@ -49,14 +50,19 @@ private:
 	int m_postid;
 	QString m_editCategory;
 	KBloggerLinkDialog *m_linkDialog;
+	KBloggerHtmlDialog *m_htmlDialog;
 private slots:
 	void loadPostSlot(KBlog::BlogPosting &posting);
 	void disconnectCategoriesSlot();
 	void toggleItalic();
 	void toggleBold();
 	void linkDialogSlot();
+	void htmlDialogSlot();
 	void addHtmlLink(QString, QString);
+	void addHtmlCode( QString );
 	void closeSignal( const int );
+	void handleSuccess( const int );
+	void handleBackendError( const QString& );
 };
 
 #endif
